liquid_swipe library

Classes

LiquidSwipe
LiquidSwipe widget for out of the box Animation between stacked Widgets.

Properties

key GlobalKey<_LiquidSwipe>
final

Typedefs

CurrentUpdateTypeCallback = void Function(UpdateType updateType)
Callback to provide the current UpdateType
OnPageChangeCallback = void Function(int activePageIndex)
Callback to provide the current page Index whenever it changes
SlidePercentCallback = void Function(double slidePercentHorizontal, double slidePercentVertical)
Callback to provide the slidePercentage, both vertical and horizontal